# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class Session(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'idle_timeout': 'int',
        'created_at': 'datetime',
        'snapshots_history': 'list[AppliedSnapshot]',
        'metrics_dashboard_url': 'str',
        'connect_url': 'str',
        'jupyter_notebook_url': 'str',
        'service_proxy_url': 'str',
        'access_token': 'str',
        'ray_dashboard_url': 'str',
        'webterminal_auth_url': 'str',
        'tensorboard_available': 'bool',
        'project_id': 'str',
        'host_name': 'str',
        'head_node_ip': 'str',
        'state': 'SessionState',
        'pending_state': 'SessionState',
        'state_data': 'SessionStateData',
        'cloud_id': 'str',
        'idle_time_remaining_seconds': 'int',
        'anyscaled_config': 'str',
        'anyscaled_config_generated_at': 'datetime',
        'allow_public_internet_traffic': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'idle_timeout': 'idle_timeout',
        'created_at': 'created_at',
        'snapshots_history': 'snapshots_history',
        'metrics_dashboard_url': 'metrics_dashboard_url',
        'connect_url': 'connect_url',
        'jupyter_notebook_url': 'jupyter_notebook_url',
        'service_proxy_url': 'service_proxy_url',
        'access_token': 'access_token',
        'ray_dashboard_url': 'ray_dashboard_url',
        'webterminal_auth_url': 'webterminal_auth_url',
        'tensorboard_available': 'tensorboard_available',
        'project_id': 'project_id',
        'host_name': 'host_name',
        'head_node_ip': 'head_node_ip',
        'state': 'state',
        'pending_state': 'pending_state',
        'state_data': 'state_data',
        'cloud_id': 'cloud_id',
        'idle_time_remaining_seconds': 'idle_time_remaining_seconds',
        'anyscaled_config': 'anyscaled_config',
        'anyscaled_config_generated_at': 'anyscaled_config_generated_at',
        'allow_public_internet_traffic': 'allow_public_internet_traffic'
    }

    def __init__(self, id=None, name=None, idle_timeout=None, created_at=None, snapshots_history=None, metrics_dashboard_url=None, connect_url=None, jupyter_notebook_url=None, service_proxy_url=None, access_token=None, ray_dashboard_url=None, webterminal_auth_url=None, tensorboard_available=None, project_id=None, host_name=None, head_node_ip=None, state=None, pending_state=None, state_data=None, cloud_id=None, idle_time_remaining_seconds=None, anyscaled_config=None, anyscaled_config_generated_at=None, allow_public_internet_traffic=False, local_vars_configuration=None):  # noqa: E501
        """Session - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._idle_timeout = None
        self._created_at = None
        self._snapshots_history = None
        self._metrics_dashboard_url = None
        self._connect_url = None
        self._jupyter_notebook_url = None
        self._service_proxy_url = None
        self._access_token = None
        self._ray_dashboard_url = None
        self._webterminal_auth_url = None
        self._tensorboard_available = None
        self._project_id = None
        self._host_name = None
        self._head_node_ip = None
        self._state = None
        self._pending_state = None
        self._state_data = None
        self._cloud_id = None
        self._idle_time_remaining_seconds = None
        self._anyscaled_config = None
        self._anyscaled_config_generated_at = None
        self._allow_public_internet_traffic = None
        self.discriminator = None

        self.id = id
        self.name = name
        if idle_timeout is not None:
            self.idle_timeout = idle_timeout
        self.created_at = created_at
        self.snapshots_history = snapshots_history
        if metrics_dashboard_url is not None:
            self.metrics_dashboard_url = metrics_dashboard_url
        if connect_url is not None:
            self.connect_url = connect_url
        if jupyter_notebook_url is not None:
            self.jupyter_notebook_url = jupyter_notebook_url
        if service_proxy_url is not None:
            self.service_proxy_url = service_proxy_url
        self.access_token = access_token
        if ray_dashboard_url is not None:
            self.ray_dashboard_url = ray_dashboard_url
        if webterminal_auth_url is not None:
            self.webterminal_auth_url = webterminal_auth_url
        self.tensorboard_available = tensorboard_available
        self.project_id = project_id
        if host_name is not None:
            self.host_name = host_name
        if head_node_ip is not None:
            self.head_node_ip = head_node_ip
        self.state = state
        if pending_state is not None:
            self.pending_state = pending_state
        if state_data is not None:
            self.state_data = state_data
        if cloud_id is not None:
            self.cloud_id = cloud_id
        if idle_time_remaining_seconds is not None:
            self.idle_time_remaining_seconds = idle_time_remaining_seconds
        if anyscaled_config is not None:
            self.anyscaled_config = anyscaled_config
        if anyscaled_config_generated_at is not None:
            self.anyscaled_config_generated_at = anyscaled_config_generated_at
        if allow_public_internet_traffic is not None:
            self.allow_public_internet_traffic = allow_public_internet_traffic

    @property
    def id(self):
        """Gets the id of this Session.  # noqa: E501


        :return: The id of this Session.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Session.


        :param id: The id of this Session.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Session.  # noqa: E501


        :return: The name of this Session.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Session.


        :param name: The name of this Session.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def idle_timeout(self):
        """Gets the idle_timeout of this Session.  # noqa: E501


        :return: The idle_timeout of this Session.  # noqa: E501
        :rtype: int
        """
        return self._idle_timeout

    @idle_timeout.setter
    def idle_timeout(self, idle_timeout):
        """Sets the idle_timeout of this Session.


        :param idle_timeout: The idle_timeout of this Session.  # noqa: E501
        :type: int
        """

        self._idle_timeout = idle_timeout

    @property
    def created_at(self):
        """Gets the created_at of this Session.  # noqa: E501


        :return: The created_at of this Session.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Session.


        :param created_at: The created_at of this Session.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def snapshots_history(self):
        """Gets the snapshots_history of this Session.  # noqa: E501


        :return: The snapshots_history of this Session.  # noqa: E501
        :rtype: list[AppliedSnapshot]
        """
        return self._snapshots_history

    @snapshots_history.setter
    def snapshots_history(self, snapshots_history):
        """Sets the snapshots_history of this Session.


        :param snapshots_history: The snapshots_history of this Session.  # noqa: E501
        :type: list[AppliedSnapshot]
        """
        if self.local_vars_configuration.client_side_validation and snapshots_history is None:  # noqa: E501
            raise ValueError("Invalid value for `snapshots_history`, must not be `None`")  # noqa: E501

        self._snapshots_history = snapshots_history

    @property
    def metrics_dashboard_url(self):
        """Gets the metrics_dashboard_url of this Session.  # noqa: E501


        :return: The metrics_dashboard_url of this Session.  # noqa: E501
        :rtype: str
        """
        return self._metrics_dashboard_url

    @metrics_dashboard_url.setter
    def metrics_dashboard_url(self, metrics_dashboard_url):
        """Sets the metrics_dashboard_url of this Session.


        :param metrics_dashboard_url: The metrics_dashboard_url of this Session.  # noqa: E501
        :type: str
        """

        self._metrics_dashboard_url = metrics_dashboard_url

    @property
    def connect_url(self):
        """Gets the connect_url of this Session.  # noqa: E501


        :return: The connect_url of this Session.  # noqa: E501
        :rtype: str
        """
        return self._connect_url

    @connect_url.setter
    def connect_url(self, connect_url):
        """Sets the connect_url of this Session.


        :param connect_url: The connect_url of this Session.  # noqa: E501
        :type: str
        """

        self._connect_url = connect_url

    @property
    def jupyter_notebook_url(self):
        """Gets the jupyter_notebook_url of this Session.  # noqa: E501


        :return: The jupyter_notebook_url of this Session.  # noqa: E501
        :rtype: str
        """
        return self._jupyter_notebook_url

    @jupyter_notebook_url.setter
    def jupyter_notebook_url(self, jupyter_notebook_url):
        """Sets the jupyter_notebook_url of this Session.


        :param jupyter_notebook_url: The jupyter_notebook_url of this Session.  # noqa: E501
        :type: str
        """

        self._jupyter_notebook_url = jupyter_notebook_url

    @property
    def service_proxy_url(self):
        """Gets the service_proxy_url of this Session.  # noqa: E501


        :return: The service_proxy_url of this Session.  # noqa: E501
        :rtype: str
        """
        return self._service_proxy_url

    @service_proxy_url.setter
    def service_proxy_url(self, service_proxy_url):
        """Sets the service_proxy_url of this Session.


        :param service_proxy_url: The service_proxy_url of this Session.  # noqa: E501
        :type: str
        """

        self._service_proxy_url = service_proxy_url

    @property
    def access_token(self):
        """Gets the access_token of this Session.  # noqa: E501


        :return: The access_token of this Session.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this Session.


        :param access_token: The access_token of this Session.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and access_token is None:  # noqa: E501
            raise ValueError("Invalid value for `access_token`, must not be `None`")  # noqa: E501

        self._access_token = access_token

    @property
    def ray_dashboard_url(self):
        """Gets the ray_dashboard_url of this Session.  # noqa: E501


        :return: The ray_dashboard_url of this Session.  # noqa: E501
        :rtype: str
        """
        return self._ray_dashboard_url

    @ray_dashboard_url.setter
    def ray_dashboard_url(self, ray_dashboard_url):
        """Sets the ray_dashboard_url of this Session.


        :param ray_dashboard_url: The ray_dashboard_url of this Session.  # noqa: E501
        :type: str
        """

        self._ray_dashboard_url = ray_dashboard_url

    @property
    def webterminal_auth_url(self):
        """Gets the webterminal_auth_url of this Session.  # noqa: E501


        :return: The webterminal_auth_url of this Session.  # noqa: E501
        :rtype: str
        """
        return self._webterminal_auth_url

    @webterminal_auth_url.setter
    def webterminal_auth_url(self, webterminal_auth_url):
        """Sets the webterminal_auth_url of this Session.


        :param webterminal_auth_url: The webterminal_auth_url of this Session.  # noqa: E501
        :type: str
        """

        self._webterminal_auth_url = webterminal_auth_url

    @property
    def tensorboard_available(self):
        """Gets the tensorboard_available of this Session.  # noqa: E501


        :return: The tensorboard_available of this Session.  # noqa: E501
        :rtype: bool
        """
        return self._tensorboard_available

    @tensorboard_available.setter
    def tensorboard_available(self, tensorboard_available):
        """Sets the tensorboard_available of this Session.


        :param tensorboard_available: The tensorboard_available of this Session.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and tensorboard_available is None:  # noqa: E501
            raise ValueError("Invalid value for `tensorboard_available`, must not be `None`")  # noqa: E501

        self._tensorboard_available = tensorboard_available

    @property
    def project_id(self):
        """Gets the project_id of this Session.  # noqa: E501


        :return: The project_id of this Session.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this Session.


        :param project_id: The project_id of this Session.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and project_id is None:  # noqa: E501
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def host_name(self):
        """Gets the host_name of this Session.  # noqa: E501


        :return: The host_name of this Session.  # noqa: E501
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this Session.


        :param host_name: The host_name of this Session.  # noqa: E501
        :type: str
        """

        self._host_name = host_name

    @property
    def head_node_ip(self):
        """Gets the head_node_ip of this Session.  # noqa: E501


        :return: The head_node_ip of this Session.  # noqa: E501
        :rtype: str
        """
        return self._head_node_ip

    @head_node_ip.setter
    def head_node_ip(self, head_node_ip):
        """Sets the head_node_ip of this Session.


        :param head_node_ip: The head_node_ip of this Session.  # noqa: E501
        :type: str
        """

        self._head_node_ip = head_node_ip

    @property
    def state(self):
        """Gets the state of this Session.  # noqa: E501


        :return: The state of this Session.  # noqa: E501
        :rtype: SessionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Session.


        :param state: The state of this Session.  # noqa: E501
        :type: SessionState
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def pending_state(self):
        """Gets the pending_state of this Session.  # noqa: E501

        The requsted state when a state change is requested or None if there is no requested state.  # noqa: E501

        :return: The pending_state of this Session.  # noqa: E501
        :rtype: SessionState
        """
        return self._pending_state

    @pending_state.setter
    def pending_state(self, pending_state):
        """Sets the pending_state of this Session.

        The requsted state when a state change is requested or None if there is no requested state.  # noqa: E501

        :param pending_state: The pending_state of this Session.  # noqa: E501
        :type: SessionState
        """

        self._pending_state = pending_state

    @property
    def state_data(self):
        """Gets the state_data of this Session.  # noqa: E501


        :return: The state_data of this Session.  # noqa: E501
        :rtype: SessionStateData
        """
        return self._state_data

    @state_data.setter
    def state_data(self, state_data):
        """Sets the state_data of this Session.


        :param state_data: The state_data of this Session.  # noqa: E501
        :type: SessionStateData
        """

        self._state_data = state_data

    @property
    def cloud_id(self):
        """Gets the cloud_id of this Session.  # noqa: E501


        :return: The cloud_id of this Session.  # noqa: E501
        :rtype: str
        """
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, cloud_id):
        """Sets the cloud_id of this Session.


        :param cloud_id: The cloud_id of this Session.  # noqa: E501
        :type: str
        """

        self._cloud_id = cloud_id

    @property
    def idle_time_remaining_seconds(self):
        """Gets the idle_time_remaining_seconds of this Session.  # noqa: E501

        The idle-time remaining in seconds before the session is auto-suspended.  # noqa: E501

        :return: The idle_time_remaining_seconds of this Session.  # noqa: E501
        :rtype: int
        """
        return self._idle_time_remaining_seconds

    @idle_time_remaining_seconds.setter
    def idle_time_remaining_seconds(self, idle_time_remaining_seconds):
        """Sets the idle_time_remaining_seconds of this Session.

        The idle-time remaining in seconds before the session is auto-suspended.  # noqa: E501

        :param idle_time_remaining_seconds: The idle_time_remaining_seconds of this Session.  # noqa: E501
        :type: int
        """

        self._idle_time_remaining_seconds = idle_time_remaining_seconds

    @property
    def anyscaled_config(self):
        """Gets the anyscaled_config of this Session.  # noqa: E501


        :return: The anyscaled_config of this Session.  # noqa: E501
        :rtype: str
        """
        return self._anyscaled_config

    @anyscaled_config.setter
    def anyscaled_config(self, anyscaled_config):
        """Sets the anyscaled_config of this Session.


        :param anyscaled_config: The anyscaled_config of this Session.  # noqa: E501
        :type: str
        """

        self._anyscaled_config = anyscaled_config

    @property
    def anyscaled_config_generated_at(self):
        """Gets the anyscaled_config_generated_at of this Session.  # noqa: E501


        :return: The anyscaled_config_generated_at of this Session.  # noqa: E501
        :rtype: datetime
        """
        return self._anyscaled_config_generated_at

    @anyscaled_config_generated_at.setter
    def anyscaled_config_generated_at(self, anyscaled_config_generated_at):
        """Sets the anyscaled_config_generated_at of this Session.


        :param anyscaled_config_generated_at: The anyscaled_config_generated_at of this Session.  # noqa: E501
        :type: datetime
        """

        self._anyscaled_config_generated_at = anyscaled_config_generated_at

    @property
    def allow_public_internet_traffic(self):
        """Gets the allow_public_internet_traffic of this Session.  # noqa: E501


        :return: The allow_public_internet_traffic of this Session.  # noqa: E501
        :rtype: bool
        """
        return self._allow_public_internet_traffic

    @allow_public_internet_traffic.setter
    def allow_public_internet_traffic(self, allow_public_internet_traffic):
        """Sets the allow_public_internet_traffic of this Session.


        :param allow_public_internet_traffic: The allow_public_internet_traffic of this Session.  # noqa: E501
        :type: bool
        """

        self._allow_public_internet_traffic = allow_public_internet_traffic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Session):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Session):
            return True

        return self.to_dict() != other.to_dict()



from unittest.mock import Mock, patch

import click
import pytest

from anyscale.cluster_env import (
    get_build_from_cluster_env_identifier,
    get_cluster_env_from_name,
    list_builds,
    validate_successful_build,
)


def test_get_build_id_from_cluster_env_identifier():
    mock_anyscale_api_client = Mock()

    mock_get_cluster_env_from_name = Mock()
    mock_list_builds = Mock(return_value=[Mock(revision=3, id="mock_build_id")])
    with patch.multiple(
        "anyscale.cluster_env",
        get_cluster_env_from_name=mock_get_cluster_env_from_name,
        list_builds=mock_list_builds,
    ):
        assert (
            get_build_from_cluster_env_identifier(
                "my_cluster_env:3", mock_anyscale_api_client
            ).id
            == "mock_build_id"
        )

    mock_list_builds = Mock(
        return_value=[
            Mock(revision=3, id="mock_build_id3"),
            Mock(revision=1, id="mock_build_id1"),
        ]
    )
    with patch.multiple(
        "anyscale.cluster_env",
        get_cluster_env_from_name=mock_get_cluster_env_from_name,
        list_builds=mock_list_builds,
    ):
        assert (
            get_build_from_cluster_env_identifier(
                "my_cluster_env", mock_anyscale_api_client
            ).id
            == "mock_build_id3"
        )

    mock_list_builds = Mock(return_value=[])
    with patch.multiple(
        "anyscale.cluster_env",
        get_cluster_env_from_name=mock_get_cluster_env_from_name,
        list_builds=mock_list_builds,
    ):
        with pytest.raises(click.ClickException):
            get_build_from_cluster_env_identifier(
                "my_cluster_env:3", mock_anyscale_api_client
            )

    mock_list_builds = Mock(return_value=[])
    with patch.multiple(
        "anyscale.cluster_env",
        get_cluster_env_from_name=mock_get_cluster_env_from_name,
        list_builds=mock_list_builds,
    ):
        with pytest.raises(click.ClickException):
            get_build_from_cluster_env_identifier(
                "my_cluster_env", mock_anyscale_api_client
            )


def test_get_cluster_env_id_from_name():
    mock_anyscale_api_client = Mock()

    mock_cluster_env = Mock(id="my_cluster_env_id")
    mock_cluster_env.name = "my_cluster_env"
    mock_anyscale_api_client.search_cluster_environments = Mock(
        return_value=Mock(results=[mock_cluster_env])
    )
    assert (
        get_cluster_env_from_name("my_cluster_env", mock_anyscale_api_client).id
        == "my_cluster_env_id"
    )
    mock_anyscale_api_client.search_cluster_environments.assert_called_once_with(
        {"name": {"equals": "my_cluster_env"}, "paging": {"count": 1}}
    )

    mock_anyscale_api_client.search_cluster_environments.return_value = Mock(results=[])
    with pytest.raises(click.ClickException):
        assert get_cluster_env_from_name("my_cluster_env", mock_anyscale_api_client)


def test_list_builds():
    mock_anyscale_api_client = Mock()

    mock_anyscale_api_client.list_cluster_environment_builds = Mock(
        return_value=Mock(
            results=["result1", "result2"], metadata=Mock(next_paging_token=None)
        )
    )
    assert list_builds("my_cluster_env_id", mock_anyscale_api_client) == [
        "result1",
        "result2",
    ]
    mock_anyscale_api_client.list_cluster_environment_builds.assert_called_once_with(
        "my_cluster_env_id", count=50, paging_token=None
    )


def test_validate_successful_build():
    # Check the function return without error for successful build
    mock_anyscale_api_client = Mock()
    mock_anyscale_api_client.get_cluster_environment_build = Mock(
        return_value=Mock(result=Mock(status="succeeded"))
    )
    validate_successful_build("mock_build_id", mock_anyscale_api_client)
    mock_anyscale_api_client.get_cluster_environment_build.assert_called_once_with(
        "mock_build_id"
    )

    # Check the function raises an error for non-successful builds
    mock_anyscale_api_client.get_cluster_environment_build = Mock(
        return_value=Mock(
            result=Mock(status="failed", cluster_environment_id="mock_cluster_env_id")
        )
    )
    with pytest.raises(click.ClickException):
        validate_successful_build("mock_build_id", mock_anyscale_api_client)
    mock_anyscale_api_client.get_cluster_environment_build.assert_called_once_with(
        "mock_build_id"
    )
    mock_anyscale_api_client.get_cluster_environment.assert_called_once_with(
        "mock_cluster_env_id"
    )



# coding: utf-8

"""
    Anyscale API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from anyscale_client.configuration import Configuration


class ActorsQuery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'TextQuery',
        'runtime_environment_id': 'str',
        'job_id': 'str',
        'cluster_id': 'str',
        'serve_deployment_id': 'str',
        'only_replicas': 'bool',
        'paging': 'PageQuery',
        'state_filter': 'list[ActorStatus]'
    }

    attribute_map = {
        'name': 'name',
        'runtime_environment_id': 'runtime_environment_id',
        'job_id': 'job_id',
        'cluster_id': 'cluster_id',
        'serve_deployment_id': 'serve_deployment_id',
        'only_replicas': 'only_replicas',
        'paging': 'paging',
        'state_filter': 'state_filter'
    }

    def __init__(self, name=None, runtime_environment_id=None, job_id=None, cluster_id=None, serve_deployment_id=None, only_replicas=None, paging=None, state_filter=[], local_vars_configuration=None):  # noqa: E501
        """ActorsQuery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._runtime_environment_id = None
        self._job_id = None
        self._cluster_id = None
        self._serve_deployment_id = None
        self._only_replicas = None
        self._paging = None
        self._state_filter = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if runtime_environment_id is not None:
            self.runtime_environment_id = runtime_environment_id
        if job_id is not None:
            self.job_id = job_id
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if serve_deployment_id is not None:
            self.serve_deployment_id = serve_deployment_id
        if only_replicas is not None:
            self.only_replicas = only_replicas
        if paging is not None:
            self.paging = paging
        if state_filter is not None:
            self.state_filter = state_filter

    @property
    def name(self):
        """Gets the name of this ActorsQuery.  # noqa: E501

        Filters Actors by name. If this field is absent, no filtering is done.  # noqa: E501

        :return: The name of this ActorsQuery.  # noqa: E501
        :rtype: TextQuery
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ActorsQuery.

        Filters Actors by name. If this field is absent, no filtering is done.  # noqa: E501

        :param name: The name of this ActorsQuery.  # noqa: E501
        :type: TextQuery
        """

        self._name = name

    @property
    def runtime_environment_id(self):
        """Gets the runtime_environment_id of this ActorsQuery.  # noqa: E501

        Filters Actors by runtime environment id. If this field is absent, no filtering is done.  # noqa: E501

        :return: The runtime_environment_id of this ActorsQuery.  # noqa: E501
        :rtype: str
        """
        return self._runtime_environment_id

    @runtime_environment_id.setter
    def runtime_environment_id(self, runtime_environment_id):
        """Sets the runtime_environment_id of this ActorsQuery.

        Filters Actors by runtime environment id. If this field is absent, no filtering is done.  # noqa: E501

        :param runtime_environment_id: The runtime_environment_id of this ActorsQuery.  # noqa: E501
        :type: str
        """

        self._runtime_environment_id = runtime_environment_id

    @property
    def job_id(self):
        """Gets the job_id of this ActorsQuery.  # noqa: E501

        Filters Actors by job id. If this field is absent, no filtering is done.  # noqa: E501

        :return: The job_id of this ActorsQuery.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ActorsQuery.

        Filters Actors by job id. If this field is absent, no filtering is done.  # noqa: E501

        :param job_id: The job_id of this ActorsQuery.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ActorsQuery.  # noqa: E501

        Filters Actors by cluster_id. If this field is absent, no filtering is done.  # noqa: E501

        :return: The cluster_id of this ActorsQuery.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ActorsQuery.

        Filters Actors by cluster_id. If this field is absent, no filtering is done.  # noqa: E501

        :param cluster_id: The cluster_id of this ActorsQuery.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def serve_deployment_id(self):
        """Gets the serve_deployment_id of this ActorsQuery.  # noqa: E501

        Filters Actors by serve_deployment_id. If this field is absent, no filtering is done.  # noqa: E501

        :return: The serve_deployment_id of this ActorsQuery.  # noqa: E501
        :rtype: str
        """
        return self._serve_deployment_id

    @serve_deployment_id.setter
    def serve_deployment_id(self, serve_deployment_id):
        """Sets the serve_deployment_id of this ActorsQuery.

        Filters Actors by serve_deployment_id. If this field is absent, no filtering is done.  # noqa: E501

        :param serve_deployment_id: The serve_deployment_id of this ActorsQuery.  # noqa: E501
        :type: str
        """

        self._serve_deployment_id = serve_deployment_id

    @property
    def only_replicas(self):
        """Gets the only_replicas of this ActorsQuery.  # noqa: E501

        Filters for Actors that are replicas by filtering out ServeController / HTTPProxyActors. Must be used in conjunction with serve_deployment_id  # noqa: E501

        :return: The only_replicas of this ActorsQuery.  # noqa: E501
        :rtype: bool
        """
        return self._only_replicas

    @only_replicas.setter
    def only_replicas(self, only_replicas):
        """Sets the only_replicas of this ActorsQuery.

        Filters for Actors that are replicas by filtering out ServeController / HTTPProxyActors. Must be used in conjunction with serve_deployment_id  # noqa: E501

        :param only_replicas: The only_replicas of this ActorsQuery.  # noqa: E501
        :type: bool
        """

        self._only_replicas = only_replicas

    @property
    def paging(self):
        """Gets the paging of this ActorsQuery.  # noqa: E501

        Pagination information.  # noqa: E501

        :return: The paging of this ActorsQuery.  # noqa: E501
        :rtype: PageQuery
        """
        return self._paging

    @paging.setter
    def paging(self, paging):
        """Sets the paging of this ActorsQuery.

        Pagination information.  # noqa: E501

        :param paging: The paging of this ActorsQuery.  # noqa: E501
        :type: PageQuery
        """

        self._paging = paging

    @property
    def state_filter(self):
        """Gets the state_filter of this ActorsQuery.  # noqa: E501

        Filter Actors by Actor Status. If this field is an empty set, no filtering is done.  # noqa: E501

        :return: The state_filter of this ActorsQuery.  # noqa: E501
        :rtype: list[ActorStatus]
        """
        return self._state_filter

    @state_filter.setter
    def state_filter(self, state_filter):
        """Sets the state_filter of this ActorsQuery.

        Filter Actors by Actor Status. If this field is an empty set, no filtering is done.  # noqa: E501

        :param state_filter: The state_filter of this ActorsQuery.  # noqa: E501
        :type: list[ActorStatus]
        """

        self._state_filter = state_filter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActorsQuery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ActorsQuery):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class ServeReplicaMetric(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'latency_p95_ms': 'float',
        'qps': 'float',
        'request_count': 'float',
        'error_count': 'float'
    }

    attribute_map = {
        'latency_p95_ms': 'latency_p95_ms',
        'qps': 'qps',
        'request_count': 'request_count',
        'error_count': 'error_count'
    }

    def __init__(self, latency_p95_ms=None, qps=None, request_count=None, error_count=None, local_vars_configuration=None):  # noqa: E501
        """ServeReplicaMetric - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._latency_p95_ms = None
        self._qps = None
        self._request_count = None
        self._error_count = None
        self.discriminator = None

        if latency_p95_ms is not None:
            self.latency_p95_ms = latency_p95_ms
        if qps is not None:
            self.qps = qps
        if request_count is not None:
            self.request_count = request_count
        if error_count is not None:
            self.error_count = error_count

    @property
    def latency_p95_ms(self):
        """Gets the latency_p95_ms of this ServeReplicaMetric.  # noqa: E501

        The p95 processing latency of this replica  # noqa: E501

        :return: The latency_p95_ms of this ServeReplicaMetric.  # noqa: E501
        :rtype: float
        """
        return self._latency_p95_ms

    @latency_p95_ms.setter
    def latency_p95_ms(self, latency_p95_ms):
        """Sets the latency_p95_ms of this ServeReplicaMetric.

        The p95 processing latency of this replica  # noqa: E501

        :param latency_p95_ms: The latency_p95_ms of this ServeReplicaMetric.  # noqa: E501
        :type: float
        """

        self._latency_p95_ms = latency_p95_ms

    @property
    def qps(self):
        """Gets the qps of this ServeReplicaMetric.  # noqa: E501

        The queries per second for this replica  # noqa: E501

        :return: The qps of this ServeReplicaMetric.  # noqa: E501
        :rtype: float
        """
        return self._qps

    @qps.setter
    def qps(self, qps):
        """Sets the qps of this ServeReplicaMetric.

        The queries per second for this replica  # noqa: E501

        :param qps: The qps of this ServeReplicaMetric.  # noqa: E501
        :type: float
        """

        self._qps = qps

    @property
    def request_count(self):
        """Gets the request_count of this ServeReplicaMetric.  # noqa: E501

        The count of request for this replica   # noqa: E501

        :return: The request_count of this ServeReplicaMetric.  # noqa: E501
        :rtype: float
        """
        return self._request_count

    @request_count.setter
    def request_count(self, request_count):
        """Sets the request_count of this ServeReplicaMetric.

        The count of request for this replica   # noqa: E501

        :param request_count: The request_count of this ServeReplicaMetric.  # noqa: E501
        :type: float
        """

        self._request_count = request_count

    @property
    def error_count(self):
        """Gets the error_count of this ServeReplicaMetric.  # noqa: E501

        The count of errors for this replica   # noqa: E501

        :return: The error_count of this ServeReplicaMetric.  # noqa: E501
        :rtype: float
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """Sets the error_count of this ServeReplicaMetric.

        The count of errors for this replica   # noqa: E501

        :param error_count: The error_count of this ServeReplicaMetric.  # noqa: E501
        :type: float
        """

        self._error_count = error_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServeReplicaMetric):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ServeReplicaMetric):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from openapi_client.models.aws_credentials import AWSCredentials
from openapi_client.models.aws_node_options import AWSNodeOptions
from openapi_client.models.aws_tag import AWSTag
from openapi_client.models.aws_tag_specification import AWSTagSpecification
from openapi_client.models.actor_lifetime import ActorLifetime
from openapi_client.models.actor_logs import ActorLogs
from openapi_client.models.actor_status import ActorStatus
from openapi_client.models.actorlogs_response import ActorlogsResponse
from openapi_client.models.add_instance_pool_member import AddInstancePoolMember
from openapi_client.models.anyscale_aws_account import AnyscaleAWSAccount
from openapi_client.models.anyscale_version_response import AnyscaleVersionResponse
from openapi_client.models.anyscaleawsaccount_response import AnyscaleawsaccountResponse
from openapi_client.models.anyscaleversionresponse_response import AnyscaleversionresponseResponse
from openapi_client.models.app_config import AppConfig
from openapi_client.models.app_config_config_schema import AppConfigConfigSchema
from openapi_client.models.appconfig_response import AppconfigResponse
from openapi_client.models.applied_snapshot import AppliedSnapshot
from openapi_client.models.archived_logs_info import ArchivedLogsInfo
from openapi_client.models.archivedlogsinfo_response import ArchivedlogsinfoResponse
from openapi_client.models.autoscaler_credentials import AutoscalerCredentials
from openapi_client.models.autoscalercredentials_response import AutoscalercredentialsResponse
from openapi_client.models.autosync_session_id import AutosyncSessionId
from openapi_client.models.autosyncsessionid_list_response import AutosyncsessionidListResponse
from openapi_client.models.autosyncsessionid_response import AutosyncsessionidResponse
from openapi_client.models.aws_region_and_zones import AwsRegionAndZones
from openapi_client.models.aws_region_info import AwsRegionInfo
from openapi_client.models.awscredentials_response import AwscredentialsResponse
from openapi_client.models.awsregionandzones_response import AwsregionandzonesResponse
from openapi_client.models.baseimagesenum import BASEIMAGESENUM
from openapi_client.models.bank_account_information import BankAccountInformation
from openapi_client.models.base_job import BaseJob
from openapi_client.models.base_job_status import BaseJobStatus
from openapi_client.models.basejob_response import BasejobResponse
from openapi_client.models.batch_response_batched_result_organization_invitation_base import BatchResponseBatchedResultOrganizationInvitationBase
from openapi_client.models.batched_result_organization_invitation_base import BatchedResultOrganizationInvitationBase
from openapi_client.models.billing_information import BillingInformation
from openapi_client.models.block_device_mapping import BlockDeviceMapping
from openapi_client.models.build import Build
from openapi_client.models.build_log_response import BuildLogResponse
from openapi_client.models.build_response import BuildResponse
from openapi_client.models.build_status import BuildStatus
from openapi_client.models.buildlogresponse_response import BuildlogresponseResponse
from openapi_client.models.card import Card
from openapi_client.models.card_id import CardId
from openapi_client.models.card_list_response import CardListResponse
from openapi_client.models.change_password_params import ChangePasswordParams
from openapi_client.models.cloud import Cloud
from openapi_client.models.cloud_config import CloudConfig
from openapi_client.models.cloud_list_response import CloudListResponse
from openapi_client.models.cloud_name_options import CloudNameOptions
from openapi_client.models.cloud_providers import CloudProviders
from openapi_client.models.cloud_response import CloudResponse
from openapi_client.models.cloud_types import CloudTypes
from openapi_client.models.cluster_config import ClusterConfig
from openapi_client.models.cluster_config_with_session_idle_timeout import ClusterConfigWithSessionIdleTimeout
from openapi_client.models.cluster_features import ClusterFeatures
from openapi_client.models.cluster_monitor_response import ClusterMonitorResponse
from openapi_client.models.cluster_status import ClusterStatus
from openapi_client.models.clusterconfig_response import ClusterconfigResponse
from openapi_client.models.clusterconfigwithsessionidletimeout_response import ClusterconfigwithsessionidletimeoutResponse
from openapi_client.models.clusterfeatures_response import ClusterfeaturesResponse
from openapi_client.models.clustermonitorresponse_response import ClustermonitorresponseResponse
from openapi_client.models.clusterstatus_response import ClusterstatusResponse
from openapi_client.models.compute_node_type import ComputeNodeType
from openapi_client.models.compute_template import ComputeTemplate
from openapi_client.models.compute_template_config import ComputeTemplateConfig
from openapi_client.models.compute_template_query import ComputeTemplateQuery
from openapi_client.models.computetemplate_response import ComputetemplateResponse
from openapi_client.models.computetemplateconfig_response import ComputetemplateconfigResponse
from openapi_client.models.create_app_config import CreateAppConfig
from openapi_client.models.create_app_config_configuration_schema import CreateAppConfigConfigurationSchema
from openapi_client.models.create_build import CreateBuild
from openapi_client.models.create_compute_template import CreateComputeTemplate
from openapi_client.models.create_from_github_options import CreateFromGithubOptions
from openapi_client.models.create_nodes_options import CreateNodesOptions
from openapi_client.models.create_organization_invitation import CreateOrganizationInvitation
from openapi_client.models.create_production_job import CreateProductionJob
from openapi_client.models.create_production_service import CreateProductionService
from openapi_client.models.create_response import CreateResponse
from openapi_client.models.create_session_from_snapshot_options import CreateSessionFromSnapshotOptions
from openapi_client.models.create_session_in_db import CreateSessionInDb
from openapi_client.models.create_snapshot_options import CreateSnapshotOptions
from openapi_client.models.create_user import CreateUser
from openapi_client.models.create_user_project_collaborator import CreateUserProjectCollaborator
from openapi_client.models.create_user_project_collaborator_value import CreateUserProjectCollaboratorValue
from openapi_client.models.credit_card_information import CreditCardInformation
from openapi_client.models.decorated_actor import DecoratedActor
from openapi_client.models.decorated_application_template import DecoratedApplicationTemplate
from openapi_client.models.decorated_build import DecoratedBuild
from openapi_client.models.decorated_compute_template import DecoratedComputeTemplate
from openapi_client.models.decorated_compute_template_config import DecoratedComputeTemplateConfig
from openapi_client.models.decorated_job import DecoratedJob
from openapi_client.models.decorated_production_job import DecoratedProductionJob
from openapi_client.models.decorated_production_job_state_transition import DecoratedProductionJobStateTransition
from openapi_client.models.decorated_runtime_env import DecoratedRuntimeEnv
from openapi_client.models.decorated_serve_deployment import DecoratedServeDeployment
from openapi_client.models.decorated_session import DecoratedSession
from openapi_client.models.decoratedactor_list_response import DecoratedactorListResponse
from openapi_client.models.decoratedactor_response import DecoratedactorResponse
from openapi_client.models.decoratedapplicationtemplate_list_response import DecoratedapplicationtemplateListResponse
from openapi_client.models.decoratedapplicationtemplate_response import DecoratedapplicationtemplateResponse
from openapi_client.models.decoratedbuild_list_response import DecoratedbuildListResponse
from openapi_client.models.decoratedbuild_response import DecoratedbuildResponse
from openapi_client.models.decoratedcomputetemplate_list_response import DecoratedcomputetemplateListResponse
from openapi_client.models.decoratedcomputetemplate_response import DecoratedcomputetemplateResponse
from openapi_client.models.decoratedjob_list_response import DecoratedjobListResponse
from openapi_client.models.decoratedjob_response import DecoratedjobResponse
from openapi_client.models.decoratedproductionjob_list_response import DecoratedproductionjobListResponse
from openapi_client.models.decoratedproductionjob_response import DecoratedproductionjobResponse
from openapi_client.models.decoratedproductionjobstatetransition_list_response import DecoratedproductionjobstatetransitionListResponse
from openapi_client.models.decoratedruntimeenv_list_response import DecoratedruntimeenvListResponse
from openapi_client.models.decoratedruntimeenv_response import DecoratedruntimeenvResponse
from openapi_client.models.decoratedservedeployment_list_response import DecoratedservedeploymentListResponse
from openapi_client.models.decoratedservedeployment_response import DecoratedservedeploymentResponse
from openapi_client.models.decoratedsession_list_response import DecoratedsessionListResponse
from openapi_client.models.decoratedsession_response import DecoratedsessionResponse
from openapi_client.models.deployment_status import DeploymentStatus
from openapi_client.models.dismissal_type import DismissalType
from openapi_client.models.ebs_block_device import EbsBlockDevice
from openapi_client.models.error import Error
from openapi_client.models.execute_command_response import ExecuteCommandResponse
from openapi_client.models.execute_interactive_command_options import ExecuteInteractiveCommandOptions
from openapi_client.models.execute_shell_command_options import ExecuteShellCommandOptions
from openapi_client.models.executecommandresponse_response import ExecutecommandresponseResponse
from openapi_client.models.external_service_status import ExternalServiceStatus
from openapi_client.models.external_service_status_response import ExternalServiceStatusResponse
from openapi_client.models.external_terminal_command import ExternalTerminalCommand
from openapi_client.models.externalservicestatusresponse_response import ExternalservicestatusresponseResponse
from openapi_client.models.feature_compatibility import FeatureCompatibility
from openapi_client.models.feature_flag_response import FeatureFlagResponse
from openapi_client.models.featureflagresponse_response import FeatureflagresponseResponse
from openapi_client.models.gcp_node_options import GCPNodeOptions
from openapi_client.models.github_project import GithubProject
from openapi_client.models.githubproject_response import GithubprojectResponse
from openapi_client.models.http_validation_error import HTTPValidationError
from openapi_client.models.ha_job_goal_states import HaJobGoalStates
from openapi_client.models.ha_job_states import HaJobStates
from openapi_client.models.ha_job_type import HaJobType
from openapi_client.models.head_ip import HeadIp
from openapi_client.models.headip_response import HeadipResponse
from openapi_client.models.historical_cost_granularity import HistoricalCostGranularity
from openapi_client.models.historical_costs import HistoricalCosts
from openapi_client.models.historicalcosts_list_response import HistoricalcostsListResponse
from openapi_client.models.iam_instance_profile_specification import IamInstanceProfileSpecification
from openapi_client.models.instance import Instance
from openapi_client.models.instance_external_ip import InstanceExternalIP
from openapi_client.models.instance_id import InstanceID
from openapi_client.models.instance_internal_ip import InstanceInternalIP
from openapi_client.models.instance_is_running import InstanceIsRunning
from openapi_client.models.instance_is_terminated import InstanceIsTerminated
from openapi_client.models.instance_list_response import InstanceListResponse
from openapi_client.models.instance_pool_member import InstancePoolMember
from openapi_client.models.instance_response import InstanceResponse
from openapi_client.models.instance_status import InstanceStatus
from openapi_client.models.instanceexternalip_response import InstanceexternalipResponse
from openapi_client.models.instanceid_response import InstanceidResponse
from openapi_client.models.instanceinternalip_response import InstanceinternalipResponse
from openapi_client.models.instanceisrunning_response import InstanceisrunningResponse
from openapi_client.models.instanceisterminated_response import InstanceisterminatedResponse
from openapi_client.models.instancepoolmember_response import InstancepoolmemberResponse
from openapi_client.models.internal_production_job import InternalProductionJob
from openapi_client.models.internalproductionjob_response import InternalproductionjobResponse
from openapi_client.models.invoice import Invoice
from openapi_client.models.invoice_list_response import InvoiceListResponse
from openapi_client.models.invoice_status import InvoiceStatus
from openapi_client.models.invoices_query import InvoicesQuery
from openapi_client.models.job_access import JobAccess
from openapi_client.models.job_run_type import JobRunType
from openapi_client.models.job_state_log_level_types import JobStateLogLevelTypes
from openapi_client.models.jobs_logs import JobsLogs
from openapi_client.models.jobslogs_response import JobslogsResponse
from openapi_client.models.json_patch_operation import JsonPatchOperation
from openapi_client.models.list_response_metadata import ListResponseMetadata
from openapi_client.models.log_level_types import LogLevelTypes
from openapi_client.models.login_user_params import LoginUserParams
from openapi_client.models.logs_output import LogsOutput
from openapi_client.models.logsoutput_response import LogsoutputResponse
from openapi_client.models.metric_period import MetricPeriod
from openapi_client.models.mini_build import MiniBuild
from openapi_client.models.mini_cloud import MiniCloud
from openapi_client.models.mini_cluster import MiniCluster
from openapi_client.models.mini_compute_template import MiniComputeTemplate
from openapi_client.models.mini_job_run import MiniJobRun
from openapi_client.models.mini_namespace import MiniNamespace
from openapi_client.models.mini_project import MiniProject
from openapi_client.models.mini_runtime_environment import MiniRuntimeEnvironment
from openapi_client.models.mini_user import MiniUser
from openapi_client.models.network_interface import NetworkInterface
from openapi_client.models.nodes_options import NodesOptions
from openapi_client.models.non_terminated_nodes_options import NonTerminatedNodesOptions
from openapi_client.models.onboarding_user_cards_query import OnboardingUserCardsQuery
from openapi_client.models.organization import Organization
from openapi_client.models.organization_availability import OrganizationAvailability
from openapi_client.models.organization_collaborator import OrganizationCollaborator
from openapi_client.models.organization_invitation import OrganizationInvitation
from openapi_client.models.organization_invitation_base import OrganizationInvitationBase
from openapi_client.models.organization_permission_level import OrganizationPermissionLevel
from openapi_client.models.organization_project_collaborator import OrganizationProjectCollaborator
from openapi_client.models.organization_project_collaborator_value import OrganizationProjectCollaboratorValue
from openapi_client.models.organization_response import OrganizationResponse
from openapi_client.models.organizationavailability_response import OrganizationavailabilityResponse
from openapi_client.models.organizationcollaborator_list_response import OrganizationcollaboratorListResponse
from openapi_client.models.organizationinvitation_list_response import OrganizationinvitationListResponse
from openapi_client.models.organizationinvitation_response import OrganizationinvitationResponse
from openapi_client.models.organizationinvitationbase_response import OrganizationinvitationbaseResponse
from openapi_client.models.organizationprojectcollaborator_list_response import OrganizationprojectcollaboratorListResponse
from openapi_client.models.permission_level import PermissionLevel
from openapi_client.models.product_type import ProductType
from openapi_client.models.production_job_config import ProductionJobConfig
from openapi_client.models.production_job_state_transition import ProductionJobStateTransition
from openapi_client.models.project import Project
from openapi_client.models.project_base import ProjectBase
from openapi_client.models.project_collaborator import ProjectCollaborator
from openapi_client.models.project_collaborator_value import ProjectCollaboratorValue
from openapi_client.models.project_collaborators_put_message import ProjectCollaboratorsPutMessage
from openapi_client.models.project_create_message import ProjectCreateMessage
from openapi_client.models.project_default_session_name import ProjectDefaultSessionName
from openapi_client.models.project_delete_message import ProjectDeleteMessage
from openapi_client.models.project_list_response import ProjectListResponse
from openapi_client.models.project_patch_message import ProjectPatchMessage
from openapi_client.models.project_response import ProjectResponse
from openapi_client.models.projectbase_response import ProjectbaseResponse
from openapi_client.models.projectcollaborator_list_response import ProjectcollaboratorListResponse
from openapi_client.models.projectdefaultsessionname_response import ProjectdefaultsessionnameResponse
from openapi_client.models.provider_metadata import ProviderMetadata
from openapi_client.models.providermetadata_response import ProvidermetadataResponse
from openapi_client.models.python_modules import PythonModules
from openapi_client.models.query_pool_size import QueryPoolSize
from openapi_client.models.ray_runtime_env_config import RayRuntimeEnvConfig
from openapi_client.models.request_instance_pool_member import RequestInstancePoolMember
from openapi_client.models.request_organization_identifiers_params import RequestOrganizationIdentifiersParams
from openapi_client.models.request_password_reset_params import RequestPasswordResetParams
from openapi_client.models.reset_password_params import ResetPasswordParams
from openapi_client.models.resource_historical_costs import ResourceHistoricalCosts
from openapi_client.models.resources import Resources
from openapi_client.models.s3_download_location import S3DownloadLocation
from openapi_client.models.sso_login_info import SSOLoginInfo
from openapi_client.models.supportedbaseimagesenum import SUPPORTEDBASEIMAGESENUM
from openapi_client.models.serve_deployment_grafana_dashboard_status import ServeDeploymentGrafanaDashboardStatus
from openapi_client.models.serve_deployment_logs import ServeDeploymentLogs
from openapi_client.models.serve_replica import ServeReplica
from openapi_client.models.serve_replica_metric import ServeReplicaMetric
from openapi_client.models.servedeploymentlogs_response import ServedeploymentlogsResponse
from openapi_client.models.server_session_token import ServerSessionToken
from openapi_client.models.servereplica_list_response import ServereplicaListResponse
from openapi_client.models.serversessiontoken_response import ServersessiontokenResponse
from openapi_client.models.service_account import ServiceAccount
from openapi_client.models.service_usage import ServiceUsage
from openapi_client.models.session import Session
from openapi_client.models.session_access import SessionAccess
from openapi_client.models.session_autosync_sessions_update_message import SessionAutosyncSessionsUpdateMessage
from openapi_client.models.session_command import SessionCommand
from openapi_client.models.session_command_finish_options import SessionCommandFinishOptions
from openapi_client.models.session_command_id import SessionCommandId
from openapi_client.models.session_command_types import SessionCommandTypes
from openapi_client.models.session_create_message import SessionCreateMessage
from openapi_client.models.session_delete_message import SessionDeleteMessage
from openapi_client.models.session_describe import SessionDescribe
from openapi_client.models.session_details import SessionDetails
from openapi_client.models.session_event import SessionEvent
from openapi_client.models.session_event_cause import SessionEventCause
from openapi_client.models.session_event_types import SessionEventTypes
from openapi_client.models.session_execute_message import SessionExecuteMessage
from openapi_client.models.session_finish_command_message import SessionFinishCommandMessage
from openapi_client.models.session_history_item import SessionHistoryItem
from openapi_client.models.session_id import SessionId
from openapi_client.models.session_kill_command_message import SessionKillCommandMessage
from openapi_client.models.session_list_response import SessionListResponse
from openapi_client.models.session_patch_message import SessionPatchMessage
from openapi_client.models.session_response import SessionResponse
from openapi_client.models.session_ssh_key import SessionSshKey
from openapi_client.models.session_starting_up_data import SessionStartingUpData
from openapi_client.models.session_state import SessionState
from openapi_client.models.session_state_change_message import SessionStateChangeMessage
from openapi_client.models.session_state_data import SessionStateData
from openapi_client.models.session_stopping_data import SessionStoppingData
from openapi_client.models.session_up_options import SessionUpOptions
from openapi_client.models.sessioncommand_list_response import SessioncommandListResponse
from openapi_client.models.sessioncommandid_response import SessioncommandidResponse
from openapi_client.models.sessiondescribe_response import SessiondescribeResponse
from openapi_client.models.sessiondetails_response import SessiondetailsResponse
from openapi_client.models.sessionevent_list_response import SessioneventListResponse
from openapi_client.models.sessionhistoryitem_list_response import SessionhistoryitemListResponse
from openapi_client.models.sessionid_response import SessionidResponse
from openapi_client.models.sessionsshkey_response import SessionsshkeyResponse
from openapi_client.models.set_node_tags_options import SetNodeTagsOptions
from openapi_client.models.setup_initialize_session_options import SetupInitializeSessionOptions
from openapi_client.models.snapshot import Snapshot
from openapi_client.models.snapshot_create import SnapshotCreate
from openapi_client.models.snapshot_create_message import SnapshotCreateMessage
from openapi_client.models.snapshot_delete import SnapshotDelete
from openapi_client.models.snapshot_delete_message import SnapshotDeleteMessage
from openapi_client.models.snapshot_files import SnapshotFiles
from openapi_client.models.snapshot_id import SnapshotID
from openapi_client.models.snapshot_list import SnapshotList
from openapi_client.models.snapshot_list_item import SnapshotListItem
from openapi_client.models.snapshot_patch_message import SnapshotPatchMessage
from openapi_client.models.snapshot_project_file import SnapshotProjectFile
from openapi_client.models.snapshot_response import SnapshotResponse
from openapi_client.models.snapshotcreate_response import SnapshotcreateResponse
from openapi_client.models.snapshotdelete_response import SnapshotdeleteResponse
from openapi_client.models.snapshotfiles_response import SnapshotfilesResponse
from openapi_client.models.snapshotid_response import SnapshotidResponse
from openapi_client.models.snapshotlist_response import SnapshotlistResponse
from openapi_client.models.socket_message_schemas import SocketMessageSchemas
from openapi_client.models.socket_message_types import SocketMessageTypes
from openapi_client.models.socketmessageschemas_response import SocketmessageschemasResponse
from openapi_client.models.socketmessagetypes_response import SocketmessagetypesResponse
from openapi_client.models.ssologininfo_response import SsologininfoResponse
from openapi_client.models.start_empty_session_response import StartEmptySessionResponse
from openapi_client.models.start_session_options import StartSessionOptions
from openapi_client.models.startemptysessionresponse_response import StartemptysessionresponseResponse
from openapi_client.models.stop_session_options import StopSessionOptions
from openapi_client.models.take_snapshot_options import TakeSnapshotOptions
from openapi_client.models.text_query import TextQuery
from openapi_client.models.update_compute_template import UpdateComputeTemplate
from openapi_client.models.update_organization_collaborator import UpdateOrganizationCollaborator
from openapi_client.models.update_project_collaborator import UpdateProjectCollaborator
from openapi_client.models.upload_session_command_logs_locations import UploadSessionCommandLogsLocations
from openapi_client.models.uploadsessioncommandlogslocations_response import UploadsessioncommandlogslocationsResponse
from openapi_client.models.user_info import UserInfo
from openapi_client.models.user_resend_email_options import UserResendEmailOptions
from openapi_client.models.userinfo_response import UserinfoResponse
from openapi_client.models.validation_error import ValidationError
from openapi_client.models.visibility import Visibility
from openapi_client.models.wait_until_stopped_options import WaitUntilStoppedOptions
from openapi_client.models.web_terminal import WebTerminal
from openapi_client.models.webterminal_list_response import WebterminalListResponse
from openapi_client.models.webterminal_response import WebterminalResponse
from openapi_client.models.worker_node_type import WorkerNodeType
from openapi_client.models.write_cloud import WriteCloud
from openapi_client.models.write_cluster_config import WriteClusterConfig
from openapi_client.models.write_project import WriteProject
from openapi_client.models.write_session import WriteSession
from openapi_client.models.write_snapshot import WriteSnapshot



from typing import Optional

import click

from anyscale.cli_logger import BlockLogger
from anyscale.controllers.service_controller import ServiceController
from anyscale.util import validate_non_negative_arg


log = BlockLogger()  # CLI Logger


@click.group(
    "service",
    help="Interact with production services running on Anyscale.",
    hidden=True,
)
def service_cli() -> None:
    pass


@service_cli.command(name="deploy", help="Deploy a service to Anyscale.")
@click.argument("service-config-file", required=True)
@click.option("--name", "-n", required=False, default=None, help="Name of service.")
@click.option(
    "--description", required=False, default=None, help="Description of service."
)
def deploy(
    service_config_file: str, name: Optional[str], description: Optional[str],
) -> None:
    service_controller = ServiceController()
    service_controller.deploy(
        service_config_file, name=name, description=description,
    )


@service_cli.command(name="list", help="Display information about existing services.")
@click.option(
    "--name", "-n", required=False, default=None, help="Filter by service name."
)
@click.option(
    "--service-id", "--id", required=False, default=None, help="Filter by service id."
)
@click.option(
    "--project-id", required=False, default=None, help="Filter by project id."
)
@click.option(
    "--include-all-users",
    is_flag=True,
    default=False,
    help="Include services not created by current user.",
)
@click.option(
    "--max-items",
    required=False,
    default=10,
    type=int,
    help="Max items to show in list.",
    callback=validate_non_negative_arg,
)
def list(
    name: Optional[str],
    service_id: Optional[str],
    project_id: Optional[str],
    include_all_users: bool,
    max_items: int,
) -> None:
    service_controller = ServiceController()
    service_controller.list(
        name=name,
        service_id=service_id,
        project_id=project_id,
        include_all_users=include_all_users,
        max_items=max_items,
    )


@service_cli.command(
    name="terminate", help="Attempt to terminate a service asynchronously."
)
@click.option("--service-id", "--id", required=False, help="Id of service.")
@click.option("--name", "-n", required=False, help="Name of service.")
def service(service_id: Optional[str], name: Optional[str]) -> None:
    service_controller = ServiceController()
    service_controller.terminate(service_id=service_id, service_name=name)



from contextlib import redirect_stderr, redirect_stdout
import io
import os
from unittest.mock import Mock, patch

import click
import pytest

from anyscale.authenticate import get_auth_api_client
from anyscale.cli_logger import BlockLogger
from anyscale.client.openapi_client.rest import ApiException as ApiExceptionInternal
from anyscale.sdk.anyscale_client.rest import ApiException as ApiExceptionExternal


def test_warning_to_stderr():
    # Test warnings are printed to stderr
    log = BlockLogger()
    f = io.StringIO()
    warning_message = "test_warning"
    with redirect_stderr(f):
        log.warning(warning_message)

    assert warning_message in f.getvalue()


def test_block():
    log = BlockLogger()

    # Test opening block, writing info, closing block
    log.open_block(block_label="block1")
    log.info("msg1", block_label="block1")
    log.close_block(block_label="block1")

    # Test error raised when opening two blocks without closing first
    log.open_block(block_label="block1")
    with pytest.raises(Exception):
        log.open_block(block_label="block2")

    # Test error raised when closing block that wasn't opened
    with pytest.raises(Exception):
        log.close_block(block_label="block2")

    # Test error raised when writing to block that wasn't opened
    with pytest.raises(Exception):
        log.info("msg2", block_label="block2")


def test_debug_env_var():
    log = BlockLogger()
    f = io.StringIO()
    debug_message = "test_debug"

    # Test debug message is not printed to stdout if ANYSCALE_DEBUG != 1
    os.environ.pop("ANYSCALE_DEBUG", None)
    with redirect_stdout(f):
        log.debug(debug_message)
    assert f.getvalue() == ""

    # Test debug message is printed to stdout if ANYSCALE_DEBUG == 1
    os.environ["ANYSCALE_DEBUG"] = "1"
    with redirect_stdout(f):
        log.debug(debug_message)
    assert debug_message in f.getvalue()


def test_format_api_exception_internal():
    # Tests that API exceptions are correctly formatted for the internal API
    BlockLogger()
    with patch.multiple(
        "anyscale.authenticate.AuthenticationBlock",
        _validate_api_client_auth=Mock(),
        _validate_credentials_format=Mock(),
    ):
        mock_api_client = get_auth_api_client(
            cli_token="fake_cli_token", host="fake_host"
        ).api_client

    # Test non ApiExceptions are not caught by log.format_api_exception
    with patch.multiple(
        "anyscale.api.openapi_client.ApiClient",
        call_api=Mock(side_effect=ZeroDivisionError()),
    ), pytest.raises(ZeroDivisionError):
        mock_api_client.get_project_api_v2_projects_project_id_get("bad_project_id")

    e = ApiExceptionInternal()
    e.headers = Mock(_container={})
    with patch.multiple(
        "anyscale.api.openapi_client.ApiClient", call_api=Mock(side_effect=e),
    ):
        # Test original ApiException is raised if ANYSCALE_DEBUG == 1
        os.environ["ANYSCALE_DEBUG"] = "1"
        with pytest.raises(ApiExceptionInternal):
            mock_api_client.get_project_api_v2_projects_project_id_get("bad_project_id")

        # Test formatted ClickException is raised if ANYSCALE_DEBUG != 1
        os.environ.pop("ANYSCALE_DEBUG", None)
        with pytest.raises(click.ClickException):
            mock_api_client.get_project_api_v2_projects_project_id_get("bad_project_id")


def test_format_api_exception_external():
    # Tests that API exceptions are correctly formatted for the external API
    BlockLogger()
    with patch.multiple(
        "anyscale.authenticate.AuthenticationBlock",
        _validate_api_client_auth=Mock(),
        _validate_credentials_format=Mock(),
    ):
        mock_api_client = get_auth_api_client(
            cli_token="fake_cli_token", host="fake_host"
        ).anyscale_api_client

    # Test non ApiExceptions are not caught by log.format_api_exception
    with patch.multiple(
        "anyscale.sdk.anyscale_client.ApiClient",
        call_api=Mock(side_effect=ZeroDivisionError()),
    ), pytest.raises(ZeroDivisionError):
        mock_api_client.list_projects()

    e = ApiExceptionExternal()
    e.headers = Mock(_container={})
    with patch.multiple(
        "anyscale.sdk.anyscale_client.ApiClient", call_api=Mock(side_effect=e),
    ):
        # Test original ApiException is raised if ANYSCALE_DEBUG == 1
        os.environ["ANYSCALE_DEBUG"] = "1"
        with pytest.raises(ApiExceptionExternal):
            mock_api_client.list_projects()

        # Test formatted ClickException is raised if ANYSCALE_DEBUG != 1
        os.environ.pop("ANYSCALE_DEBUG", None)
        with pytest.raises(click.ClickException):
            mock_api_client.list_projects()



from multiprocessing import Process
from pathlib import Path
from types import SimpleNamespace
from typing import List
from unittest.mock import Mock, patch

import pytest
from tests.test_connect import _make_test_builder

from anyscale.background.job_context import BackgroundJobContext
from anyscale.background.job_runner import (
    _generate_job_name,
    BackgroundJobRunner,
    run,
    run_kill_child,
)
from anyscale.connect import ClientBuilder
from anyscale.shared_anyscale_utils.conf import (
    ANYSCALE_BACKGROUND_JOB_CONTEXT,
    BACKGROUND_ACTOR_NAME,
)


def test_job_runner_actor():
    """
    Test that the job runner actor is passing the correct args to the subprocess
    """
    mock_runtime_env = {"uris": ["a", "b", "c"]}
    mock_ray = Mock()
    mock_ray.get_runtime_context.return_value.runtime_env = mock_runtime_env

    mock_run_kill_child = Mock()

    mock_actor_handle = Mock()
    mock_actor_handle.stop.remote = Mock()

    mock_os = Mock()
    mock_os.environ = {}

    context = BackgroundJobContext("creator", "cmd", "ns", [], "par_job_id")

    with patch.dict("sys.modules", ray=mock_ray, os=mock_os), patch.multiple(
        "anyscale.background.job_runner",
        os=mock_os,
        run_kill_child=mock_run_kill_child,
    ):
        runner = BackgroundJobRunner()
        runner.run_background_job("cmd", mock_actor_handle, context)

        context.runtime_env_uris = mock_runtime_env["uris"]

        mock_run_kill_child.assert_called_once_with(
            "cmd",
            shell=True,
            check=True,
            env={
                "PYTHONUNBUFFERED": "1",  # Make sure python subprocess streams logs https://docs.python.org/3/using/cmdline.html#cmdoption-u
                "RAY_ADDRESS": "anyscale://",  # Make sure that internal ray.init has an anyscale RAY_ADDRESS
                ANYSCALE_BACKGROUND_JOB_CONTEXT: context.to_json(),
            },
        )

        mock_actor_handle.stop.remote.assert_called_once()


def test_generate_command_name_default() -> None:
    """
    Test generation of job name default from command
    """

    assert _generate_job_name("python abc.py") == "python_abc_py"
    assert _generate_job_name("rllib train -f train.py") == "rllib_train_f_train_py"
    assert _generate_job_name("./my_script.sh") == "_my_script_sh"


def test_non_anyscale_address() -> None:
    """
    Test that anyscale.background.run fails for non anyscale addresses
    """
    try:
        run("cmd", {"pip": "r"}, "ray://")
    except ValueError:
        pass
    except Exception:
        pytest.fail("ray:// address should not be accepted")


def test_run_job(tmp_path: Path):
    """
    Tests the anyscale.background.run function
    Ensure that data is passed into ray correctly
    Ensure the context is set correctly
    """
    builder, _, _, _ = _make_test_builder(tmp_path)
    mock_background_job_runner = Mock()
    builder.connect = Mock()
    cluster_id = "cluster_id"
    builder.connect.return_value.anyscale_cluster_info.cluster_id = cluster_id
    builder._job_config.metadata["creator_id"] = "cid"
    builder._anyscale_sdk.search_jobs.return_value.results = [
        SimpleNamespace(id="job_id")
    ]
    mock_client_builder = Mock(return_value=builder)
    mock_uuid = Mock(return_value="ns")
    mock_get_runtime_ctx = Mock()
    mock_get_runtime_ctx.return_value.job_id.hex.return_value = "par_job_id"

    with patch.multiple("anyscale", ClientBuilder=mock_client_builder), patch(
        "ray.remote", new=Mock(return_value=mock_background_job_runner),
    ), patch("uuid.uuid4", new=mock_uuid), patch(
        "ray.get_runtime_context", new=mock_get_runtime_ctx
    ):

        address = "anyscale://cluster"
        job = run("cmd", {"pip": "r"}, address)
        mock_client_builder.assert_called_once_with("cluster")
        mock_uuid.assert_called_once()

        b: ClientBuilder = builder
        b._job_config.set_ray_namespace.assert_called_once_with("bg_ns")
        b._job_config.set_metadata.assert_called_with("job_name", "cmd")
        b._job_config.set_metadata.has_call("inherit_from_child", "1")

        mock_background_job_runner.options.assert_called_once_with(
            lifetime="detached", name=BACKGROUND_ACTOR_NAME
        )

        context = BackgroundJobContext(
            "cid",
            "cmd",
            namespace="bg_ns",
            runtime_env_uris=[],
            parent_ray_job_id="par_job_id",
        )
        actor = mock_background_job_runner.options.return_value.remote.return_value
        mock_background_job_runner.options.return_value.remote.return_value.run_background_job.remote.assert_called_once_with(
            command="cmd", context=context, self_handle=actor,
        )

        # Check that we are waiting for the job correctly
        b._anyscale_sdk.search_jobs.assert_called_once_with(
            {"ray_job_id": "par_job_id", "cluster_id": cluster_id}
        )

        assert job.context == context

        # Check the private variables and make sure they are correct
        assert job._BackgroundJob__actor == actor  # type: ignore
        assert job.ref == actor.run_background_job.remote.return_value  # type: ignore
        assert job.id == "job_id"


def _run_in_new_process():
    run_kill_child(
        "echo 'mfjrk' && sleep 5 && echo 'do not print this'", shell=True,
    )


async def test_run_kill_child():
    import asyncio

    import psutil

    p = Process(target=_run_in_new_process)
    p.start()

    main_pid = p.pid
    main_process = psutil.Process(main_pid)

    await asyncio.sleep(2)
    all_children: List[psutil.Process] = main_process.children(recursive=True)

    assert len(all_children) > 2  # assert that children were spawned
    for child in all_children:
        assert child.is_running()  # assert that all children are running
    p.terminate()
    p.join()

    await asyncio.sleep(2)
    # Assert that all of the children are dead
    for child in all_children:
        assert not child.is_running()



# coding: utf-8

# flake8: noqa

"""
    Anyscale API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from anyscale_client.api.default_api import DefaultApi

# import ApiClient
from anyscale_client.api_client import ApiClient
from anyscale_client.configuration import Configuration
from anyscale_client.exceptions import OpenApiException
from anyscale_client.exceptions import ApiTypeError
from anyscale_client.exceptions import ApiValueError
from anyscale_client.exceptions import ApiKeyError
from anyscale_client.exceptions import ApiException
# import models into sdk package
from anyscale_client.models.aws_credentials import AWSCredentials
from anyscale_client.models.aws_node_options import AWSNodeOptions
from anyscale_client.models.aws_tag import AWSTag
from anyscale_client.models.aws_tag_specification import AWSTagSpecification
from anyscale_client.models.actor import Actor
from anyscale_client.models.actor_lifetime import ActorLifetime
from anyscale_client.models.actor_list_response import ActorListResponse
from anyscale_client.models.actor_logs import ActorLogs
from anyscale_client.models.actor_response import ActorResponse
from anyscale_client.models.actor_status import ActorStatus
from anyscale_client.models.actorlogs_response import ActorlogsResponse
from anyscale_client.models.actors_query import ActorsQuery
from anyscale_client.models.anyscaled_config import AnyscaledConfig
from anyscale_client.models.anyscaled_dataplane_config import AnyscaledDataplaneConfig
from anyscale_client.models.anyscaledconfig_response import AnyscaledconfigResponse
from anyscale_client.models.anyscaleddataplaneconfig_response import AnyscaleddataplaneconfigResponse
from anyscale_client.models.app_config import AppConfig
from anyscale_client.models.app_config_config_schema import AppConfigConfigSchema
from anyscale_client.models.appconfig_list_response import AppconfigListResponse
from anyscale_client.models.appconfig_response import AppconfigResponse
from anyscale_client.models.awscredentials_response import AwscredentialsResponse
from anyscale_client.models.baseimagesenum import BASEIMAGESENUM
from anyscale_client.models.base_job_status import BaseJobStatus
from anyscale_client.models.block_device_mapping import BlockDeviceMapping
from anyscale_client.models.build import Build
from anyscale_client.models.build_list_response import BuildListResponse
from anyscale_client.models.build_log_response import BuildLogResponse
from anyscale_client.models.build_response import BuildResponse
from anyscale_client.models.build_status import BuildStatus
from anyscale_client.models.buildlogresponse_response import BuildlogresponseResponse
from anyscale_client.models.cloud import Cloud
from anyscale_client.models.cloud_config import CloudConfig
from anyscale_client.models.cloud_list_response import CloudListResponse
from anyscale_client.models.cloud_providers import CloudProviders
from anyscale_client.models.cloud_response import CloudResponse
from anyscale_client.models.cloud_types import CloudTypes
from anyscale_client.models.clouds_query import CloudsQuery
from anyscale_client.models.cluster import Cluster
from anyscale_client.models.cluster_compute import ClusterCompute
from anyscale_client.models.cluster_compute_config import ClusterComputeConfig
from anyscale_client.models.cluster_computes_query import ClusterComputesQuery
from anyscale_client.models.cluster_environment import ClusterEnvironment
from anyscale_client.models.cluster_environment_build import ClusterEnvironmentBuild
from anyscale_client.models.cluster_environment_build_log_response import ClusterEnvironmentBuildLogResponse
from anyscale_client.models.cluster_environment_build_operation import ClusterEnvironmentBuildOperation
from anyscale_client.models.cluster_environment_build_status import ClusterEnvironmentBuildStatus
from anyscale_client.models.cluster_environments_query import ClusterEnvironmentsQuery
from anyscale_client.models.cluster_head_node_info import ClusterHeadNodeInfo
from anyscale_client.models.cluster_list_response import ClusterListResponse
from anyscale_client.models.cluster_operation import ClusterOperation
from anyscale_client.models.cluster_operation_type import ClusterOperationType
from anyscale_client.models.cluster_response import ClusterResponse
from anyscale_client.models.cluster_services_urls import ClusterServicesUrls
from anyscale_client.models.cluster_state import ClusterState
from anyscale_client.models.clustercompute_list_response import ClustercomputeListResponse
from anyscale_client.models.clustercompute_response import ClustercomputeResponse
from anyscale_client.models.clusterenvironment_list_response import ClusterenvironmentListResponse
from anyscale_client.models.clusterenvironment_response import ClusterenvironmentResponse
from anyscale_client.models.clusterenvironmentbuild_list_response import ClusterenvironmentbuildListResponse
from anyscale_client.models.clusterenvironmentbuild_response import ClusterenvironmentbuildResponse
from anyscale_client.models.clusterenvironmentbuildlogresponse_response import ClusterenvironmentbuildlogresponseResponse
from anyscale_client.models.clusterenvironmentbuildoperation_response import ClusterenvironmentbuildoperationResponse
from anyscale_client.models.clusteroperation_response import ClusteroperationResponse
from anyscale_client.models.clusters_query import ClustersQuery
from anyscale_client.models.compute_node_type import ComputeNodeType
from anyscale_client.models.compute_template import ComputeTemplate
from anyscale_client.models.compute_template_config import ComputeTemplateConfig
from anyscale_client.models.compute_template_query import ComputeTemplateQuery
from anyscale_client.models.computetemplate_list_response import ComputetemplateListResponse
from anyscale_client.models.computetemplate_response import ComputetemplateResponse
from anyscale_client.models.computetemplateconfig_response import ComputetemplateconfigResponse
from anyscale_client.models.create_app_config import CreateAppConfig
from anyscale_client.models.create_app_config_configuration_schema import CreateAppConfigConfigurationSchema
from anyscale_client.models.create_build import CreateBuild
from anyscale_client.models.create_cloud import CreateCloud
from anyscale_client.models.create_cluster import CreateCluster
from anyscale_client.models.create_cluster_compute import CreateClusterCompute
from anyscale_client.models.create_cluster_compute_config import CreateClusterComputeConfig
from anyscale_client.models.create_cluster_environment import CreateClusterEnvironment
from anyscale_client.models.create_cluster_environment_build import CreateClusterEnvironmentBuild
from anyscale_client.models.create_cluster_environment_configuration_schema import CreateClusterEnvironmentConfigurationSchema
from anyscale_client.models.create_compute_template import CreateComputeTemplate
from anyscale_client.models.create_production_job import CreateProductionJob
from anyscale_client.models.create_production_service import CreateProductionService
from anyscale_client.models.create_project import CreateProject
from anyscale_client.models.create_response import CreateResponse
from anyscale_client.models.create_sso_config import CreateSSOConfig
from anyscale_client.models.create_session import CreateSession
from anyscale_client.models.create_session_command import CreateSessionCommand
from anyscale_client.models.ebs_block_device import EbsBlockDevice
from anyscale_client.models.gcp_node_options import GCPNodeOptions
from anyscale_client.models.http_validation_error import HTTPValidationError
from anyscale_client.models.ha_job_goal_states import HaJobGoalStates
from anyscale_client.models.ha_job_states import HaJobStates
from anyscale_client.models.iam_instance_profile_specification import IamInstanceProfileSpecification
from anyscale_client.models.job import Job
from anyscale_client.models.job_list_response import JobListResponse
from anyscale_client.models.job_response import JobResponse
from anyscale_client.models.job_run_type import JobRunType
from anyscale_client.models.job_status import JobStatus
from anyscale_client.models.jobs_logs import JobsLogs
from anyscale_client.models.jobs_query import JobsQuery
from anyscale_client.models.jobslogs_response import JobslogsResponse
from anyscale_client.models.list_response_metadata import ListResponseMetadata
from anyscale_client.models.log_level_types import LogLevelTypes
from anyscale_client.models.namespace import Namespace
from anyscale_client.models.namespace_response import NamespaceResponse
from anyscale_client.models.network_interface import NetworkInterface
from anyscale_client.models.object_storage_config import ObjectStorageConfig
from anyscale_client.models.object_storage_config_s3 import ObjectStorageConfigS3
from anyscale_client.models.objectstorageconfig_response import ObjectstorageconfigResponse
from anyscale_client.models.operation_error import OperationError
from anyscale_client.models.operation_progress import OperationProgress
from anyscale_client.models.operation_result import OperationResult
from anyscale_client.models.organization import Organization
from anyscale_client.models.organization_response import OrganizationResponse
from anyscale_client.models.page_query import PageQuery
from anyscale_client.models.production_job import ProductionJob
from anyscale_client.models.production_job_config import ProductionJobConfig
from anyscale_client.models.production_job_state_transition import ProductionJobStateTransition
from anyscale_client.models.production_service import ProductionService
from anyscale_client.models.productionjob_list_response import ProductionjobListResponse
from anyscale_client.models.productionjob_response import ProductionjobResponse
from anyscale_client.models.productionservice_list_response import ProductionserviceListResponse
from anyscale_client.models.productionservice_response import ProductionserviceResponse
from anyscale_client.models.project import Project
from anyscale_client.models.project_list_response import ProjectListResponse
from anyscale_client.models.project_response import ProjectResponse
from anyscale_client.models.projects_query import ProjectsQuery
from anyscale_client.models.python_modules import PythonModules
from anyscale_client.models.python_version import PythonVersion
from anyscale_client.models.ray_runtime_env_config import RayRuntimeEnvConfig
from anyscale_client.models.resources import Resources
from anyscale_client.models.runtime_environment import RuntimeEnvironment
from anyscale_client.models.runtimeenvironment_response import RuntimeenvironmentResponse
from anyscale_client.models.sso_config import SSOConfig
from anyscale_client.models.sso_mode import SSOMode
from anyscale_client.models.supportedbaseimagesenum import SUPPORTEDBASEIMAGESENUM
from anyscale_client.models.service_account import ServiceAccount
from anyscale_client.models.session import Session
from anyscale_client.models.session_command import SessionCommand
from anyscale_client.models.session_command_types import SessionCommandTypes
from anyscale_client.models.session_event import SessionEvent
from anyscale_client.models.session_event_cause import SessionEventCause
from anyscale_client.models.session_event_types import SessionEventTypes
from anyscale_client.models.session_list_response import SessionListResponse
from anyscale_client.models.session_operation import SessionOperation
from anyscale_client.models.session_operation_type import SessionOperationType
from anyscale_client.models.session_response import SessionResponse
from anyscale_client.models.session_starting_up_data import SessionStartingUpData
from anyscale_client.models.session_state import SessionState
from anyscale_client.models.session_state_data import SessionStateData
from anyscale_client.models.session_stopping_data import SessionStoppingData
from anyscale_client.models.sessioncommand_list_response import SessioncommandListResponse
from anyscale_client.models.sessioncommand_response import SessioncommandResponse
from anyscale_client.models.sessionevent_list_response import SessioneventListResponse
from anyscale_client.models.sessionoperation_response import SessionoperationResponse
from anyscale_client.models.sessions_query import SessionsQuery
from anyscale_client.models.ssoconfig_response import SsoconfigResponse
from anyscale_client.models.start_cluster_options import StartClusterOptions
from anyscale_client.models.start_session_options import StartSessionOptions
from anyscale_client.models.static_sso_config import StaticSSOConfig
from anyscale_client.models.terminate_cluster_options import TerminateClusterOptions
from anyscale_client.models.terminate_session_options import TerminateSessionOptions
from anyscale_client.models.text_query import TextQuery
from anyscale_client.models.update_app_config import UpdateAppConfig
from anyscale_client.models.update_cloud import UpdateCloud
from anyscale_client.models.update_cluster import UpdateCluster
from anyscale_client.models.update_compute_template import UpdateComputeTemplate
from anyscale_client.models.update_organization import UpdateOrganization
from anyscale_client.models.update_project import UpdateProject
from anyscale_client.models.update_session import UpdateSession
from anyscale_client.models.validation_error import ValidationError
from anyscale_client.models.worker_node_type import WorkerNodeType




from anyscale.authenticate import get_auth_api_client


class BaseController:
    """
    Base controller which all CLI command controllers should inherit from. Implements
    common functionality of:
        - Authenticating and getting internal and external API clients
    """

    def __init__(self, initialize_auth_api_client: bool = True) -> None:
        self.initialize_auth_api_client = initialize_auth_api_client
        if self.initialize_auth_api_client:
            self.auth_api_client = get_auth_api_client()
            self.api_client = self.auth_api_client.api_client
            self.anyscale_api_client = self.auth_api_client.anyscale_api_client

    @property
    def api_client(self):
        assert self.initialize_auth_api_client, (
            "This command uses `api_client`. Please call the CLI command controller "
            "with initialize_auth_api_client=True to initialize the `api_client`"
        )
        return self._api_client

    @api_client.setter
    def api_client(self, value):
        self._api_client = value

    @property
    def anyscale_api_client(self):
        assert self.initialize_auth_api_client, (
            "This command uses `anyscale_api_client`. Please call the CLI command controller "
            "with initialize_auth_api_client=True to initialize the `anyscale_api_client`"
        )
        return self._anyscale_api_client

    @anyscale_api_client.setter
    def anyscale_api_client(self, value):
        self._anyscale_api_client = value



# coding: utf-8

"""
    Anyscale API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from anyscale_client.configuration import Configuration


class CreateSession(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'project_id': 'str',
        'cloud_id': 'str',
        'cluster_config': 'str',
        'build_id': 'str',
        'compute_template_id': 'str',
        'idle_timeout': 'int',
        'uses_app_config': 'bool',
        'allow_public_internet_traffic': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'project_id': 'project_id',
        'cloud_id': 'cloud_id',
        'cluster_config': 'cluster_config',
        'build_id': 'build_id',
        'compute_template_id': 'compute_template_id',
        'idle_timeout': 'idle_timeout',
        'uses_app_config': 'uses_app_config',
        'allow_public_internet_traffic': 'allow_public_internet_traffic'
    }

    def __init__(self, name=None, project_id=None, cloud_id=None, cluster_config=None, build_id=None, compute_template_id=None, idle_timeout=120, uses_app_config=False, allow_public_internet_traffic=False, local_vars_configuration=None):  # noqa: E501
        """CreateSession - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._project_id = None
        self._cloud_id = None
        self._cluster_config = None
        self._build_id = None
        self._compute_template_id = None
        self._idle_timeout = None
        self._uses_app_config = None
        self._allow_public_internet_traffic = None
        self.discriminator = None

        self.name = name
        self.project_id = project_id
        if cloud_id is not None:
            self.cloud_id = cloud_id
        if cluster_config is not None:
            self.cluster_config = cluster_config
        if build_id is not None:
            self.build_id = build_id
        if compute_template_id is not None:
            self.compute_template_id = compute_template_id
        if idle_timeout is not None:
            self.idle_timeout = idle_timeout
        if uses_app_config is not None:
            self.uses_app_config = uses_app_config
        if allow_public_internet_traffic is not None:
            self.allow_public_internet_traffic = allow_public_internet_traffic

    @property
    def name(self):
        """Gets the name of this CreateSession.  # noqa: E501

        Name of the session to be created.  # noqa: E501

        :return: The name of this CreateSession.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateSession.

        Name of the session to be created.  # noqa: E501

        :param name: The name of this CreateSession.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this CreateSession.  # noqa: E501

        Project that the session will be created in.  # noqa: E501

        :return: The project_id of this CreateSession.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this CreateSession.

        Project that the session will be created in.  # noqa: E501

        :param project_id: The project_id of this CreateSession.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and project_id is None:  # noqa: E501
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def cloud_id(self):
        """Gets the cloud_id of this CreateSession.  # noqa: E501

        Cloud that the session will use.  # noqa: E501

        :return: The cloud_id of this CreateSession.  # noqa: E501
        :rtype: str
        """
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, cloud_id):
        """Sets the cloud_id of this CreateSession.

        Cloud that the session will use.  # noqa: E501

        :param cloud_id: The cloud_id of this CreateSession.  # noqa: E501
        :type: str
        """

        self._cloud_id = cloud_id

    @property
    def cluster_config(self):
        """Gets the cluster_config of this CreateSession.  # noqa: E501

        Cluster config that the session can later be started with.  # noqa: E501

        :return: The cluster_config of this CreateSession.  # noqa: E501
        :rtype: str
        """
        return self._cluster_config

    @cluster_config.setter
    def cluster_config(self, cluster_config):
        """Sets the cluster_config of this CreateSession.

        Cluster config that the session can later be started with.  # noqa: E501

        :param cluster_config: The cluster_config of this CreateSession.  # noqa: E501
        :type: str
        """

        self._cluster_config = cluster_config

    @property
    def build_id(self):
        """Gets the build_id of this CreateSession.  # noqa: E501

        ID of the Build that this session was started with.  # noqa: E501

        :return: The build_id of this CreateSession.  # noqa: E501
        :rtype: str
        """
        return self._build_id

    @build_id.setter
    def build_id(self, build_id):
        """Sets the build_id of this CreateSession.

        ID of the Build that this session was started with.  # noqa: E501

        :param build_id: The build_id of this CreateSession.  # noqa: E501
        :type: str
        """

        self._build_id = build_id

    @property
    def compute_template_id(self):
        """Gets the compute_template_id of this CreateSession.  # noqa: E501

        ID of the compute template that this session was started with.  # noqa: E501

        :return: The compute_template_id of this CreateSession.  # noqa: E501
        :rtype: str
        """
        return self._compute_template_id

    @compute_template_id.setter
    def compute_template_id(self, compute_template_id):
        """Sets the compute_template_id of this CreateSession.

        ID of the compute template that this session was started with.  # noqa: E501

        :param compute_template_id: The compute_template_id of this CreateSession.  # noqa: E501
        :type: str
        """

        self._compute_template_id = compute_template_id

    @property
    def idle_timeout(self):
        """Gets the idle_timeout of this CreateSession.  # noqa: E501

        Idle timeout (in minutes), after which the session is stopped. Idle time is defined as the time during which a session is not running a user command (through 'anyscale exec' or the Web UI), and does not have an attached driver. Time spent running Jupyter commands, or commands run through ssh, is still considered 'idle'.  # noqa: E501

        :return: The idle_timeout of this CreateSession.  # noqa: E501
        :rtype: int
        """
        return self._idle_timeout

    @idle_timeout.setter
    def idle_timeout(self, idle_timeout):
        """Sets the idle_timeout of this CreateSession.

        Idle timeout (in minutes), after which the session is stopped. Idle time is defined as the time during which a session is not running a user command (through 'anyscale exec' or the Web UI), and does not have an attached driver. Time spent running Jupyter commands, or commands run through ssh, is still considered 'idle'.  # noqa: E501

        :param idle_timeout: The idle_timeout of this CreateSession.  # noqa: E501
        :type: int
        """

        self._idle_timeout = idle_timeout

    @property
    def uses_app_config(self):
        """Gets the uses_app_config of this CreateSession.  # noqa: E501

        Whether or not the session uses app config. If true, it means this is not a legacy session started with cluster yaml.  # noqa: E501

        :return: The uses_app_config of this CreateSession.  # noqa: E501
        :rtype: bool
        """
        return self._uses_app_config

    @uses_app_config.setter
    def uses_app_config(self, uses_app_config):
        """Sets the uses_app_config of this CreateSession.

        Whether or not the session uses app config. If true, it means this is not a legacy session started with cluster yaml.  # noqa: E501

        :param uses_app_config: The uses_app_config of this CreateSession.  # noqa: E501
        :type: bool
        """

        self._uses_app_config = uses_app_config

    @property
    def allow_public_internet_traffic(self):
        """Gets the allow_public_internet_traffic of this CreateSession.  # noqa: E501

        Whether public internet traffic can access Serve endpoints or if an authentication token is required.  # noqa: E501

        :return: The allow_public_internet_traffic of this CreateSession.  # noqa: E501
        :rtype: bool
        """
        return self._allow_public_internet_traffic

    @allow_public_internet_traffic.setter
    def allow_public_internet_traffic(self, allow_public_internet_traffic):
        """Sets the allow_public_internet_traffic of this CreateSession.

        Whether public internet traffic can access Serve endpoints or if an authentication token is required.  # noqa: E501

        :param allow_public_internet_traffic: The allow_public_internet_traffic of this CreateSession.  # noqa: E501
        :type: bool
        """

        self._allow_public_internet_traffic = allow_public_internet_traffic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSession):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateSession):
            return True

        return self.to_dict() != other.to_dict()
